==> haskell-wai-cors-0.2.7-367-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-GSUk0zM1b7sFtug1c4yYgT
key:                  wai-cors-0.2.7-GSUk0zM1b7sFtug1c4yYgT
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  a5f4da443757f1a242d3eb0e3cebc8b5
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-GSUk0zM1b7sFtug1c4yYgT
depends:
    attoparsec-0.14.4-DN7s9Fr9c113K5agmmE0LB base-4.16.4.0
    base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-C9u4G83SV6G4MBj88LrUbo
    http-types-0.12.4-G97153ZIeGq6X7uXEs2l2V mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-BNQtAxBTTmbBe7Crr2a2xg

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-368-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-IxOxunW7cHA5ymjhDO2TIy
key:                  wai-cors-0.2.7-IxOxunW7cHA5ymjhDO2TIy
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  9200adb6eadf020a38f1e5acd93e87f9
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-IxOxunW7cHA5ymjhDO2TIy
depends:
    attoparsec-0.14.4-J9YnXPtrDPmCdtF55eYIY2 base-4.16.4.0
    base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6njWxjerTHa1UxnauQh5c6
    http-types-0.12.4-1L1OgfMGc2W7Nfzsv4RpMF mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-ANZD32r1nfA59aypXbDlil

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
